@@ -268,7 +268,7 @@ class CERNIdentityProvider(IdentityProvider):
     def get_identity_groups(self, identifier):
         with self._get_api_session() as api_session:
             resp = api_session.get(f'{self.authz_api_base}/api/v1.0/IdentityMembership/{identifier}/precomputed')
-            if resp.status_code == 404:
+            if resp.status_code == 404 or resp.status_code == 500:
                 return set()
             resp.raise_for_status()
             results = resp.json()['data']
